import {
  initVendorConsentsLoader,
  addVendorLoadedEventListener
} from '@adv-ui/vendor-by-consents-loader'
import {vendorsConfig} from './config'
import HOTJAR_PATHS from './hotjarPaths'

const initHotjarScript = () => {
  window.hj =
    window.hj ||
    function() {
      ;(window.hj.q = window.hj.q || []).push(arguments)
    }
  window._hjSettings = {hjid: 223746, hjsv: 5}
}

const validatePath = paths => {
  return paths?.includes(window.location.pathname)
}

const getPortal = () => {
  const match = window.location.href.match(/infojobs(\w*)\.(\w*)/)
  if (match) {
    const [, , portal] = match
    return portal === 'it' ? 'it' : 'es'
  }
  return 'es'
}

const loader = async () => {
  const portal = getPortal()
  const isHotjarEnabled = validatePath(HOTJAR_PATHS[portal])
  isHotjarEnabled && initHotjarScript()
  initVendorConsentsLoader({
    vendors: {...(isHotjarEnabled && {hotjar: vendorsConfig.hotjar})}
  })

  addVendorLoadedEventListener(({vendor}) => {
    vendor === 'hotjar' && console.log('hotjar has been loaded')
  })
}

export default loader
